@@ -1,4 +1,5 @@
 // Copyright (C) 2006-2014 David Sugar, Tycho Softworks.
+// Copyright (C) 2015 Cherokees of Idaho.
 //
 // This file is part of GNU uCommon C++.
 //
@@ -1727,6 +1728,23 @@ char *String::strip(char *str, const char *clist)
     return str;
 }
 
+bool String::check(const char *str, size_t max, size_t min)
+{
+    size_t count = 0;
+
+    if(!str)
+        return false;
+
+    while(*str) {
+        if(++count > max)
+            return false;
+        ++str;
+    }
+    if(count < min)
+        return false;
+    return true;
+}
+
 void String::upper(char *str)
 {
     while(str && *str) {
