@@ -1,4 +1,5 @@
 // Copyright (C) 2010-2014 David Sugar, Tycho Softworks.
+// Copyright (C) 2015 Cherokees of Idaho.
 //
 // This file is part of GNU uCommon C++.
 //
@@ -69,7 +70,7 @@ static void dirpath(bool middle, String path, bool top = true)
         output(middle, path);
 }
 
-PROGRAM_MAIN(argc, argv)
+int main(int argc, char **argv)
 {
     unsigned count = 0;
     char *ep;
@@ -84,11 +85,11 @@ PROGRAM_MAIN(argc, argv)
         printf("%s\n", _TEXT("Options:"));
         shell::help();
         printf("\n%s\n", _TEXT("Report bugs to dyfet@gnu.org"));
-        PROGRAM_EXIT(0);
+        return 0;
     }
 
     if(!args())
-        PROGRAM_EXIT(0);
+        return 0;
 
     if(quote[0]) {
         if(!quote[1]) {
@@ -137,6 +138,6 @@ PROGRAM_MAIN(argc, argv)
     if(!lines)
         file::cout << "\n";
 
-    PROGRAM_EXIT(0);
+    return 0;
 }
 
